==> haskell-http3-0.0.2-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http3
version:              0.0.2
visibility:           public
id:                   http3-0.0.2-DGXeW9cHpZHEhNFFgHEhX
key:                  http3-0.0.2-DGXeW9cHpZHEhNFFgHEhX
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  fb698a4fd0711ae03c240b2ea920fe70
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http3-0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http3-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.2-DGXeW9cHpZHEhNFFgHEhX
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-C9u4G83SV6G4MBj88LrUbo containers-0.6.5.1
    http-types-0.12.4-G97153ZIeGq6X7uXEs2l2V
    http2-4.1.0-9dFUn2y6oEy7OCz316Wmhk
    network-3.1.4.0-I7hY9PROidqFfCvyq23hqh
    network-byte-order-0.1.7-8Wb9MBmdsnYAp65wZlMSzk
    quic-0.1.6-5h7pX9sGX51E8uJIeMFT3Y
    sockaddr-0.0.1-EEU3erYtFrv51WVNpGrruk stm-2.5.0.2
    time-manager-0.0.1-JUYb2IzyoCgA0tGDfZ4ulL
    unliftio-0.2.25.0-I5KL8dbXVmE3dWILMxzDhI

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http3-0.0.2-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http3
version:              0.0.2
visibility:           public
id:                   http3-0.0.2-3ByyJvn0xXGFwP2xEKDGZz
key:                  http3-0.0.2-3ByyJvn0xXGFwP2xEKDGZz
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  e13da56e7daac56901cdd1ea3f765b09
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/http3-0.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http3-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.2-3ByyJvn0xXGFwP2xEKDGZz
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    case-insensitive-1.2.1.0-6njWxjerTHa1UxnauQh5c6 containers-0.6.5.1
    http-types-0.12.4-1L1OgfMGc2W7Nfzsv4RpMF
    http2-4.1.0-EmiPLWCwOJhCwN7QPs9igQ
    network-3.1.4.0-9GJKuf6EY6MAL0cwpbhHGu
    network-byte-order-0.1.7-8Wb9MBmdsnYAp65wZlMSzk
    quic-0.1.6-Eg7v5iI95leA4VwNexLaHE
    sockaddr-0.0.1-KxMvFhYsJyO1b7pKWkQP5h stm-2.5.0.2
    time-manager-0.0.1-LTa6V1laKJPDDmQ52tw5PI
    unliftio-0.2.25.0-BTZsTmRO5MMERl490t8n4B

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
